export default extensions;
declare namespace extensions {
    /**
     * Open the given URL in mobile Safari browser.
     * The browser will be started automatically if it is not running.
     *
     * @param {string} url - The URL to be opened.
     */
    function openUrl(url: string): Promise<void>;
    /**
     * Clean up the directories for mobile Safari.
     * Safari will be terminated if it is running.
     *
     * @param {boolean} keepPrefs - Whether to keep Safari preferences from being deleted.
     */
    function scrubSafari(keepPrefs?: boolean): Promise<void>;
    /**
     * Updates variious Safari settings. Simulator must be booted in order to for it
     * to success.
     *
     * @param {object} updates An object containing Safari settings to be updated.
     * The list of available setting names and their values could be retrived by
     * changing the corresponding Safari settings in the UI and then inspecting
     * 'Library/Preferences/com.apple.mobilesafari.plist' file inside of
     * com.apple.mobilesafari app container.
     * The full path to the Mobile Safari's container could be retrieved from
     * `xcrun simctl get_app_container <sim_udid> com.apple.mobilesafari data`
     * command output.
     * Use the `xcrun simctl spawn <sim_udid> defaults read <path_to_plist>` command
     * to print the plist content to the Terminal.
     */
    function updateSafariSettings(updates: any): Promise<any>;
}
//# sourceMappingURL=safari.d.ts.map