export default extensions;
declare namespace extensions {
    /**
     * Updates Reduce Motion setting state.
     *
     * @param {boolean} reduceMotion Whether to enable or disable the setting.
     */
    function setReduceMotion(reduceMotion: boolean): Promise<boolean>;
    /**
     * Updates Reduce Transparency setting state.
     *
     * @param {boolean} reduceTransparency Whether to enable or disable the setting.
     */
    function setReduceTransparency(reduceTransparency: boolean): Promise<boolean>;
    /**
     * Allows to update Simulator preferences in runtime.
     *
     * @param {string} domain The name of preferences domain to be updated,
     * for example, 'com.apple.Preferences' or 'com.apple.Accessibility' or
     * full path to a plist file on the local file system.
     * @param {object} updates Mapping of keys/values to be updated
     * @returns {Promise<boolean>} True if settings were actually changed
     */
    function updateSettings(domain: string, updates: any): Promise<boolean>;
    /**
     * Sets UI appearance style.
     * This function can only be called on a booted simulator.
     *
     * @since Xcode SDK 11.4
     */
    function setAppearance(): Promise<never>;
    /**
     * Gets the current UI appearance style
     * This function can only be called on a booted simulator.
     *
     * @since Xcode SDK 11.4
     */
    function getAppearance(): Promise<never>;
    function configureLocalization(): Promise<never>;
    /**
     * Updates Auto Fill Passwords setting state.
     *
     * @param {boolean} isEnabled Whether to enable or disable the setting.
     */
    function setAutoFillPasswords(isEnabled: boolean): Promise<boolean>;
}
//# sourceMappingURL=settings.d.ts.map