"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const simulator_xcode_9_1 = __importDefault(require("./simulator-xcode-9"));
const teen_process_1 = require("teen_process");
const logger_1 = __importDefault(require("./logger"));
class SimulatorXcode93 extends simulator_xcode_9_1.default {
    constructor(udid, xcodeVersion) {
        super(udid, xcodeVersion);
        this.webInspectorSocket = null;
    }
    /*
     * @override
     */
    async getWebInspectorSocket() {
        if (this.webInspectorSocket) {
            return this.webInspectorSocket;
        }
        // lsof -aUc launchd_sim gives a set of records like
        // https://github.com/appium/appium-ios-simulator/commit/c00901a9ddea178c5581a7a57d96d8cee3f17c59#diff-2be09dd2ea01cfd6bbbd73e10bc468da782a297365eec706999fc3709c01478dR102
        // these _appear_ to always be grouped together by PID for each simulator.
        // Therefore, by obtaining simulator PID with an expected simulator UDID,
        // we can get the correct `com.apple.webinspectord_sim.socket`
        // without depending on the order of `lsof -aUc launchd_sim` result.
        const { stdout } = await (0, teen_process_1.exec)('lsof', ['-aUc', 'launchd_sim']);
        const udidPattern = `([0-9]{1,5}).+${this.udid}`;
        const udidMatch = stdout.match(new RegExp(udidPattern));
        if (!udidMatch) {
            logger_1.default.debug(`Failed to get Web Inspector socket. lsof result: ${stdout}`);
            return null;
        }
        const pidPattern = `${udidMatch[1]}.+\\s+(\\S+com\\.apple\\.webinspectord_sim\\.socket)`;
        const pidMatch = stdout.match(new RegExp(pidPattern));
        if (!pidMatch) {
            logger_1.default.debug(`Failed to get Web Inspector socket. lsof result: ${stdout}`);
            return null;
        }
        this.webInspectorSocket = pidMatch[1];
        return this.webInspectorSocket;
    }
}
exports.default = SimulatorXcode93;
//# sourceMappingURL=simulator-xcode-9.3.js.map